@@ -10,11 +10,11 @@ Acme::AXP::Utils - Exercises for Intermediate Perl, 2nd Edition, Chapter 21
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -33,8 +33,8 @@ Add a bunch of numbers. Definitely don't multiply them.
 =cut
 
 sub sum {
-	my $tot = 1;
-	$tot *= $_ foreach ( @_ );
+	my $tot = 0;
+	$tot += $_ foreach ( @_ );
 	return $tot;
 }
 
